# rf24-rs

[rf24-rs-badge]: https://img.shields.io/crates/v/rf24-rs
[rf24-rs-link]: https://crates.io/crates/rf24-rs
[rf24-rs-msrv]: https://img.shields.io/crates/msrv/rf24-rs
[rf24-rs-docs-badge]: https://img.shields.io/docsrs/rf24-rs
[rf24-rs-docs-link]: https://docs.rs/rf24-rs
[changelog-badge]: https://img.shields.io/badge/keep_a_change_log-v1.1.0-ffec3d
[changelog-link]: https://rf24-rs.readthedocs.io/en/latest/rf24-rs-changelog/

[![Crates.io Version][rf24-rs-badge]][rf24-rs-link]
[![docs.rs][rf24-rs-docs-badge]][rf24-rs-docs-link]
![Crates.io MSRV][rf24-rs-msrv]
 [![CHANGELOG][changelog-badge]][changelog-link]

This crate is a rust driver library for the nRF24L01 wireless transceivers.

## Examples

Examples are located in the [rf24-rs repository](https://github.com/nRF24/rf24-rs/tree/main/examples/rust).
